==> require-analyzer-0.2.13.tgz: package/test/error-states-test.js <==
/*
 * require-analyzer-test.js: tests for require-analyzer's handling of error states.
 *
 * (C) 2010, Nodejitsu Inc.
 *
 */
 
require.paths.unshift(require('path').join(__dirname, '..', 'lib'));

var fs = require('fs'),
    path = require('path'),
    vows = require('vows'),
    assert = require('assert'),
    analyzer = require('require-analyzer');

vows.describe('require-analyzer').addBatch({
  "When using require-analyzer": {
    "the file() method": {
      "when passed a file with errors": {
        topic: function () {
          analyzer.file({ target: path.join(__dirname, 'fixtures', 'throw-error') }, this.callback)
        },
        "should respond with an error": function (err, pkgs) {
          assert.isNotNull(err);
        }
      },
      "when passed a file with falsey throws": {
        topic: function () {
          analyzer.file({ target: path.join(__dirname, 'fixtures', 'falsey-error') }, this.callback)
        },
        "should respond with an error": function (err, pkgs) {
          assert.isNotNull(err);
        }
      },
      "when passed a file with stack overflows": {
        topic: function () {
          analyzer.file({ target: path.join(__dirname, 'fixtures', 'stack-overflow-error') }, this.callback)
        },
        "should respond with an error": function (err, pkgs) {
          assert.isNotNull(err);
        }
      },
      "when passed a file with syntax-errors": {
        topic: function () {
          analyzer.file({ target: path.join(__dirname, 'fixtures', 'syntax-error') }, this.callback)
        },
        "should respond with an error": function (err, pkgs) {
          assert.isNotNull(err);
        }
      }
    }
  }
}).export(module);

==> require-analyzer-0.3.4.tgz: package/test/error-states-test.js <==
/*
 * require-analyzer-test.js: tests for require-analyzer's handling of error states.
 *
 * (C) 2010, Nodejitsu Inc.
 *
 */
 
var fs = require('fs'),
    path = require('path'),
    vows = require('vows'),
    assert = require('assert'),
    analyzer = require('../lib/require-analyzer');

vows.describe('require-analyzer').addBatch({
  "When using require-analyzer": {
    "the file() method": {
      "when passed a file with errors": {
        topic: function () {
          analyzer.file({ target: path.join(__dirname, 'fixtures', 'throw-error') }, this.callback)
        },
        "should respond with an error": function (err, pkgs) {
          assert.isNotNull(err);
        }
      },
      "when passed a file with falsey throws": {
        topic: function () {
          analyzer.file({ target: path.join(__dirname, 'fixtures', 'falsey-error') }, this.callback)
        },
        "should respond with an error": function (err, pkgs) {
          assert.isNotNull(err);
        }
      },
      "when passed a file with stack overflows": {
        topic: function () {
          analyzer.file({ target: path.join(__dirname, 'fixtures', 'stack-overflow-error') }, this.callback)
        },
        "should respond with an error": function (err, pkgs) {
          assert.isNotNull(err);
        }
      },
      "when passed a file with syntax-errors": {
        topic: function () {
          analyzer.file({ target: path.join(__dirname, 'fixtures', 'syntax-error') }, this.callback)
        },
        "should respond with an error": function (err, pkgs) {
          assert.isNotNull(err);
        }
      }
    }
  }
}).export(module);
